==> cscec5b-op-impl-3.0.0-20220921.085300-6-sources.jar: com/ejianc/business/op/bean/ApplyDetailEntity.java <==
package com.ejianc.business.op.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 申请子实体
 *
 * @author generator
 *
 */
 @TableName("ejc_op_apply_detail")
public class ApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="apply_id")
    private Long applyId; // 主表主键
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="spec")
    private String spec; // 型号
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="reason")
    private String reason; // 出场原因
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="op_material_id")
    private Long opMaterialId; // 出门物资主键




    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getOpMaterialId() {
        return opMaterialId;
    }

    public void setOpMaterialId(Long opMaterialId) {
        this.opMaterialId = opMaterialId;
    }

}

==> cscec5b-op-impl-3.0.0-20220923.064238-14-sources.jar: com/ejianc/business/op/bean/ApplyDetailEntity.java <==
package com.ejianc.business.op.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 申请子实体
 *
 * @author generator
 *
 */
 @TableName("ejc_op_apply_detail")
public class ApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="apply_id")
    private Long applyId; // 主表主键
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="spec")
    private String spec; // 型号
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="reason")
    private String reason; // 出场原因
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="op_material_id")
    private Long opMaterialId; // 出门物资主键
    @TableField(value="op_material_spec_id")
    private Long opMaterialSpecId; // 出门物资规格主键
    @TableField(value="op_material_unit_id")
    private Long opMaterialUnitId; // 出门物资单位主键




    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getOpMaterialId() {
        return opMaterialId;
    }

    public void setOpMaterialId(Long opMaterialId) {
        this.opMaterialId = opMaterialId;
    }

    public Long getOpMaterialSpecId() {
        return opMaterialSpecId;
    }

    public void setOpMaterialSpecId(Long opMaterialSpecId) {
        this.opMaterialSpecId = opMaterialSpecId;
    }

    public Long getOpMaterialUnitId() {
        return opMaterialUnitId;
    }

    public void setOpMaterialUnitId(Long opMaterialUnitId) {
        this.opMaterialUnitId = opMaterialUnitId;
    }
}
